@@ -61,8 +61,12 @@ class GF2:
 
     def __call__(self, x: int | list | tuple | range | map):
         if isinstance(x, list|tuple|range|map):
-            return [GF2nPoint(xx, self) for xx in x]
-        return GF2nPoint(x, self)
+            if isinstance(x, bytes | bytearray):
+                return [ GF2nPoint(int.from_bytes(x, byteorder=self.byteorder), self) for xx in x]
+            return [GF2nPoint(int(xx) % self.order, self) for xx in x]
+        if isinstance(x, bytes | bytearray):
+            return GF2nPoint(int.from_bytes(x, byteorder=self.byteorder), self)
+        return GF2nPoint(int(x) % self.order, self)
 
     def __len__(self):
         return self.order
@@ -80,26 +84,26 @@ class GF2:
         return isinstance(other, GF2nPoint) and self == other.field
 
     def _factors(self) -> dict:
-        "Return the factroization order of the group order of GF(2^n)^*."
+        "Return the factroization of the group order of GF(2^n)^*."
         if not self.factors:
             self.factors = factorint(self.mult_order)
         return self.factors
 
     def zero(self) -> bool:
         "Return zero."
-        return self(0)
+        return GF2nPoint(0, self)
 
     def one(self) -> bool:
         "Return one."
         if self.bitreversed:
-            return self(self.order - 1)
-        return self(1)
+            return GF2nPoint(self.order >> 1, self)
+        return GF2nPoint(1, self)
 
     def random(self, num: int = 0) -> "GF2nPoint":
         "Return a single random point or a list of random points."
         if num:
-            return([self(randint(0,self.order-1)) for _ in range(num)])
-        return self(randint(0,self.order-1))
+            return([GF2nPoint(randint(0,self.order-1), self) for _ in range(num)])
+        return GF2nPoint(randint(0,self.order-1), self)
 
     def is_cyclic(self) -> bool:
         "GF(2^n)^* is cyclic."
@@ -112,9 +116,9 @@ class GF2:
     def generator(self) -> int | None:
         "Return a generator of the group GF(2^n)^*."
         if self.degree == 1:
-            return self(1)
+            return self.one()
         for a in range(2, self.order):
-            a = self(a)
+            a = GF2nPoint(a, self)
             if a.is_generator():
                 return a
 
@@ -129,16 +133,21 @@ class GF2:
     def star(self) -> list:
         "Return a generator for all elements of the group GF(2^n)n^*."
         for x in range(1, self.order):
-            yield self(x)
+            yield GF2nPoint(x, self)
 
+    def poly(self) -> Poly:
+        "Return the associated irreducible polynomial."
+        coeff = [int(d) for d in str(
+            format(self.modulus, "b"))]
+        if self.bitreversed:
+            return Poly(coeff + [1])
+        return Poly(list(reversed(coeff)))
 
 class GF2nPoint:
     "Represents a point in the Galois field GF(2^n)."
 
     def __init__(self, x: int, field: "GF2"):
-        if isinstance(x, bytes | bytearray):
-            x = int.from_bytes(x, byteorder=field.byteorder)
-        self.x = int(x) % field.order
+        self.x = x
         self.field = field
 
     def __repr__(self):
@@ -162,13 +171,11 @@ class GF2nPoint:
 
     def bits(self) -> list:
         "Convert to a list of bits."
+        coeff = [int(d) for d in str(
+            format(self.x, "0" + str(self.field.degree) + "b"))]
         if self.field.bitreversed:
-            coeff = [int(d) for d in str(
-                format(self.x, "0" + str(self.field.degree) + "b"))]
-        else:
-            coeff = reversed([int(d) for d in str(
-                format(self.x, "0" + str(self.field.degree) + "b"))])
-        return list(coeff)
+            return coeff
+        return list(reversed(coeff))
 
     def poly(self) -> "Poly":
         "Convert to a polynomial."
@@ -193,7 +200,7 @@ class GF2nPoint:
             return NotImplemented
         if self.field != other.field:
             raise NotImplementedError("Cannot add elements from different fields.")
-        return self.field(self.x ^ other.x)
+        return self.__class__(self.x ^ other.x, self.field)
 
     __sub__ = __add__
 
@@ -206,7 +213,7 @@ class GF2nPoint:
         if isinstance(other, int):
             if other % 2:
                 return self
-            return self.field(0)
+            return self.__class__(0, self.field)
         if not isinstance(other, self.__class__):
             return NotImplemented
         if self.field != other.field:
@@ -232,13 +239,13 @@ class GF2nPoint:
                 y <<= 1
                 if y & bitmap1:
                     y ^= self.field.modulus
-        return self.field(z)
+        return self.__class__(z, self.field)
 
     def __rmul__(self, scalar: int) -> "GF2nPoint":
         if isinstance(scalar, int):
             if scalar % 2:
                 return self
-            return self.field(0)
+            return self.__class__(0, self.field)
         return NotImplemented
 
     def __truediv__(self, other: "GF2nPoint") -> "GF2nPoint":
@@ -255,14 +262,16 @@ class GF2nPoint:
             return NotImplemented
         if not (self.x) and j < 0:
             raise ValueError("Division by zero.")
+        j %= self.field.order - 1
         if self.field.order == 2:
+            if j == 0:
+                return self.field.one()
             return self
         if self.field.bitreversed:
-            res = self.field(self.field.order >> 1)
+            res = self.__class__(self.field.order >> 1, self.field)
         else:
-            res = self.field(1)
-        x = self.field(self.x)
-        j %= self.field.order - 1
+            res = self.__class__(1, self.field)
+        x = self.__class__(self.x, self.field)
         while j > 0:
             # If j is odd, multiply with x
             if j & 1:
@@ -276,13 +285,13 @@ class GF2nPoint:
         "Cyclic rotation to the left."
         x = self.x << j
         x = (x % self.field.order) + (x // self.field.order)
-        return self.field(x)
+        return self.__class__(self.x, self.field)
 
     def __rshift__(self, j: int) -> "GF2nPoint":
         "Cyclic rotation to the right."
         x = self.x >> j
         x += (self.field.order >> j) * (self.x % 2**j)
-        return self.field(x)
+        return self.__class__(self.x, self.field)
 
     def sqrt(self) -> "GF2nPoint":
         "Compute the square root."
@@ -308,6 +317,17 @@ class GF2nPoint:
         "Test if the point is a generator of the group GF(2^n)^*."
         return self.field.mult_order == self.order()
 
+    def minpoly(self) -> Poly:
+        "Return the minimal polynomial of an element."
+        aj = self
+        mpoly = Poly([aj, self.field.one()])
+        for _ in range(1, self.field.degree):
+            aj = aj**2  # Frobenius
+            if aj == self:
+                break
+            mpoly *= Poly([aj, self.field.one()])
+        return mpoly
+
     def sbox(self, inv: bool = False) -> "GF2nPoint":
         "Apply the AES sbox."
         if self.field.degree == 8 and self.field.modulus == 0b100011011: # AES
