@@ -43,8 +43,8 @@ class Zmod:
 
     def __call__(self, x: int | list | tuple | range | map):
         if isinstance(x, list|tuple|range|map):
-            return [ZmodPoint(xx, self) for xx in x]
-        return ZmodPoint(x, self)
+            return [ZmodPoint(int(xx), self) for xx in x]
+        return ZmodPoint(int(x), self)
 
     def __iter__(self):
         for x in range(self.n):
@@ -157,7 +157,7 @@ class ZmodPoint:
     "Represents a point in the ring Zmod."
 
     def __init__(self, x: int, ring: "Zmod"):
-        self.x = int(x) % ring.n
+        self.x = x % ring.n
         self.ring = ring
 
     def __repr__(self):
@@ -247,8 +247,11 @@ class ZmodPoint:
 
     def sharp(self):
         "Returns a symmetric (w.r.t. 0) representative."
-        tmp = (self.ring.n - 1) // 2
-        return (self.x + tmp) % self.ring.n - tmp
+        if self.x <= self.ring.n // 2:
+            return self.x
+        return self.x - self.ring.n
+
+    mods = sharp
 
     def order(self) -> int:
         "Compute the order of the point in the group Z_n^*."
