@@ -67,7 +67,7 @@ class EC_Weierstrass():
         return ECPoint(x, y, self, short)
 
     def __iter__(self):
-        yield ECPoint(None, None, self)
+        yield self.inf()
         for x in range(self.p):
             y2 = int(x**3 + self.a * x + self.b)
             y = sqrt_mod(y2, self.p)
@@ -89,6 +89,10 @@ class EC_Weierstrass():
             return True
         return P.y**2 == P.x**3 + self.a * P.x + self.b
 
+    def inf(self):
+        "Point at infinity"
+        return ECPoint(None, None, self)
+
     def info(self):
         "Display some basic info on the curve"
         out = "Weierstrass curve y^2 = x^3"
@@ -125,7 +129,7 @@ class EC_Weierstrass():
 
     def mult(self, j: int, x, y):  # Addition-subtraction ladder
         "Point multiplication"
-        if j == 0:
+        if j == 0 or x is None:
             return None, None
         if j < 0:
             y = -y
@@ -160,7 +164,6 @@ class EC_Weierstrass():
 
     def psi(self, n: int):
         """The x-part of the n'th division polynomial."""
-
         if len(self.psi_list) < 5:
             self.psi_list = [ Poly([i], ring=self.gf) for i in range(3)]
             self.psi_list += [ Poly([-self.a * self.a, 12 * self.b, 6 * self.a, 0, 3], ring=self.gf) ]
@@ -343,6 +346,8 @@ class ECPoint:
 
     def order(self) -> int:
         """Compute the order of an element."""
+        if self.x is None:
+            return 1
         self.curve.factor_order()  # Make sure the factorization is available
         order = self.curve.group_order
         for p, k in self.curve.group_order_factors.items():
