@@ -1,4 +1,5 @@
-import pytest
+# pragma pylint: disable=C0114,C0116
+import pytest  # pylint: disable=W0611
 from kryptools import factorint, is_prime
 
 
@@ -12,7 +13,7 @@ def myprod(factors: dict) -> int:
 
 def test_factorint():
     assert factorint(0) == {0: 1}
-    assert factorint(1) == {}
+    assert factorint(1) == {}  # pylint: disable=C1803
     for n in (1489576198567193874913874619387459183543154617315437135656,
               2**128 - 1,
               4521089809**7):
